@@ -52,7 +52,6 @@ typedef struct {
 } CPUFireApplet;
 
 static GladeXML *xml = NULL;
-static gchar* glade_file=NULL;
 
 static unsigned int cpufire_flame[256] = {
   0x000000, 0x000001, 0x000002, 0x000003, 0x000004, 0x000005, 0x000006, 0x000007,
@@ -201,7 +200,9 @@ cpufire_applet_properties_dialog (BonoboUIComponent *uic, CPUFireApplet *applet)
 	}
 
 	if (global_property_box == NULL) {
-		xml = glade_xml_new (glade_file, NULL, NULL);
+		xml = glade_xml_new (DATADIR "/cpufire-applet.glade",
+				NULL, NULL);
+
 		glade_property_box = glade_xml_get_widget (xml,"dialog1");
 	}
 
@@ -742,9 +743,6 @@ cpufire_applet_fill (CPUFireApplet* applet)
 	gtk_tooltips_enable(applet->tooltips);
 
 	glade_gnome_init ();
-	glade_file = gnome_program_locate_file
-		(NULL, GNOME_FILE_DOMAIN_DATADIR,
-		 "cpufire-applet/cpufire-applet.glade", FALSE, NULL);
 
 	panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
 			NULL,
